@@ -29,13 +29,10 @@ setGeneric("descriptions<-",
     function (x, value) standardGeneric("descriptions<-"), signature="x")
 setGeneric("emails", function (x) standardGeneric("emails"))
 setGeneric("types", function (x) standardGeneric("types"))
+setGeneric("timestamps", function (x) standardGeneric("timestamps"))
 
 setGeneric("type", function (x) standardGeneric("type"))
 setGeneric("type<-", function (x, value) standardGeneric("type<-"))
-setGeneric("preUpload", function (x) standardGeneric("preUpload"), signature="x")
-setGeneric("postUpload",
-    function (source.var, crunch.var) standardGeneric("postUpload"),
-    signature="source.var")
 
 setGeneric("categories", function (x) standardGeneric("categories"))
 setGeneric("categories<-", function (x, value) standardGeneric("categories<-"))
@@ -139,4 +136,6 @@ NULL
 ##' @export
 setGeneric("jsonprep", function (x, ...) standardGeneric("jsonprep"))
 
+setGeneric("getShowContent", 
+    function (x, ...) standardGeneric("getShowContent"))
 
