@@ -1,11 +1,6 @@
 context("API calling")
 
 if (run.integration.tests) {
-    test_that("crunchConfig has right structure", {
-        skip("Not needed?")
-        expect_identical(getOption("httr_config")$sslversion, "SSLVERSION_TLSv1_2")
-    })
-    
     test_that("Request headers", {
         r <- try(crGET("http://httpbin.org/gzip"))
         expect_true(r$gzipped)
@@ -15,13 +10,14 @@ if (run.integration.tests) {
 
     test_that("crunchUserAgent", {
         expect_true(grepl("rcrunch", crunchUserAgent()))
-        expect_false(is.error(try(crunchUserAgent("anotherpackage/3.1.4"))))
+        expect_true(grepl("libcurl", crunchUserAgent()))
+        expect_that(try(crunchUserAgent("anotherpackage/3.1.4")), is_not_an_error())
         expect_true(grepl("anotherpackage", crunchUserAgent("anotherpackage")))
     })
     
     with(test.authentication, 
         test_that("API root can be fetched", {
-            expect_false(is.error(try(getAPIroot())))
+            expect_that(try(getAPIroot()), is_not_an_error())
             urls <- getAPIroot()
             expect_true(is.shojiObject(urls))
         }))
