@@ -24,7 +24,7 @@ if (run.integration.tests) {
                 })
                 out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("identical datasets with arrays can append", {
-                    expect_false(is.error(out))
+                    expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
                     expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
@@ -79,7 +79,7 @@ if (run.integration.tests) {
                     expect_identical(refresh(part2), part2)
                 })
                 test_that("unbound subvariables get lined up", {
-                    expect_false(is.error(out))
+                    expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
                     expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
@@ -134,7 +134,7 @@ if (run.integration.tests) {
                 })
                 out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("unbound subvars with not identical cats", {
-                    expect_false(is.error(out))
+                    expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
                     expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
@@ -176,7 +176,7 @@ if (run.integration.tests) {
                 })
                 out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("arrays with different subvariables can append", {
-                    expect_false(is.error(out))
+                    expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
                     expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
