@@ -1,19 +1,17 @@
 context("Timings")
 
 
-skip({
-if (run.integration.tests) {
-    with(test.authentication, {
-        with(test.dataset(), {
-            with(timed.HTTP("hierarchical_timings.tsv"), {
-                for (i in as.vector(outer(letters, letters, FUN=paste0))) {
-                    ds[[i]] <- rnorm(5)
-                }
-            })
-        })
-    })
-}
-})
+# if (run.integration.tests) {
+#     with(test.authentication, {
+#         with(test.dataset(), {
+#             with(timed.HTTP("hierarchical_timings.tsv"), {
+#                 for (i in as.vector(outer(letters, letters, FUN=paste0))) {
+#                     ds[[i]] <- rnorm(5)
+#                 }
+#             })
+#         })
+#     })
+# }
 
 
 mockArrayDataset <- function (nvars, nsubvars=5, nrows=3) {
