@@ -1,7 +1,5 @@
 context("Update a dataset")
 
-## For functional transformations, distinguish between "do this update to fix this data once" and "do this to every batch I append too"?
-
 if (run.integration.tests) {
     with(test.authentication, {
         with(test.dataset(df), {
@@ -132,55 +130,5 @@ if (run.integration.tests) {
                 expect_identical(sum(is.na(as.vector(ds$v3))), 10L)
             })
         })
-        
-        with(test.dataset(mrdf), {
-            ds <- mrdf.setup(ds)
-            test_that("Subvariable values before trying to update", {
-                expect_equivalent(as.vector(ds$CA$mr_1), 
-                    as.factor(c("1.0", "0.0", "1.0", NA)))
-                expect_equivalent(as.vector(ds$CA$mr_2), 
-                    as.factor(c("0.0", "0.0", "1.0", NA)))
-                expect_equivalent(as.vector(ds$CA$mr_3), 
-                    as.factor(c("0.0", "0.0", "1.0", NA)))
-            })
-            try(ds$CA[ds$v4 == "B"] <- c("1.0"))
-            test_that("Can update array subvariables", {
-                expect_equivalent(as.vector(ds$CA$mr_1), 
-                    as.factor(c("1.0", "0.0", "1.0", NA)))
-                expect_equivalent(as.vector(ds$CA$mr_2), 
-                    as.factor(c("1.0", "0.0", "1.0", NA)))
-                expect_equivalent(as.vector(ds$CA$mr_3), 
-                    as.factor(c("1.0", "0.0", "1.0", NA)))
-            })
-        })
-        
-        with(test.dataset(df), {
-            len <- try(length(as.vector(ds$v4[ds$v4 == "B"])))
-            test_that("setup for update with wrong number of values", {
-                expect_identical(len, 10L)
-            })
-            test_that("Trying to update with too many values fails", {
-                skip_on_jenkins("Silence the error emails")
-                expect_error(ds$v4[ds$v4 == "B"] <- rep(1, len + 5), 
-                    "expected 10 values, got 15")
-            })
-            test_that("Trying to update with too few values fails", {
-                skip_on_jenkins("Silence the error emails")
-                expect_error(ds$v4[ds$v4 == "B"] <- rep(1, len - 3), 
-                    "expected 10 values, got 7")
-            })
-            test_that("Trying to update with different filters fails", {
-                expect_error(ds$v4[ds$v4 == "B"] <- ds$v4[ds$v4 == "C"], 
-                    "Cannot update a variable with a value that has a different filter")
-                expect_equivalent(as.numeric(table(ds$v4)), c(10, 10))
-                try(ds$v4[ds$v4 == "B"] <- as.vector(ds$v4[ds$v4 == "C"]))
-                expect_true(all(as.vector(ds$v4) == "C"))
-            })
-            
-            test_that("Trying to update with the wrong data type fails", {
-                expect_error(ds$v3[is.na(ds$v1)] <- letters[3:7],
-                    "Cannot update NumericVariable with type character")
-            })
-        })
     })
 }
\ No newline at end of file
